# -*- encoding: utf-8 -*-
# Module MainPage

#
# Toolbox ia636 (in alphabetical order)
#

__version__ = 'ia636 Python Toolbox for Teaching Image  Processing version 0.11.7 26th Aug 2014'

from iaapplylut import iaapplylut
from iabwlp import iabwlp
from iacircle import iacircle
from iacolorhist import iacolorhist
from iacolormap import iacolormap
from iacomb import iacomb
from iacontour import iacontour
from iaconv import iaconv
from iacorr import iacorr
from iacos import iacos
from iacrop import iacrop
from iadct import iadct
from iadctmatrix import iadctmatrix
from iadft import iadft
from iadftmatrix import iadftmatrix
from iadither import iadither
from iadftview import iadftview
from iaellipse import iaellipse
from iaffine import iaffine
from iaffine3 import iaffine3
from iafftshift import iafftshift
from iafig2img import iafig2img
from iafloyd import iafloyd
from iaftemplate import iaftemplate
from iagaussian import iagaussian
from iageorigid import iageorigid
from iagshow import iagshow
from iah2percentile import iah2percentile
from iah2stats import iah2stats
from iahaarmatrix import iahaarmatrix
from iahadamard import iahadamard
from iahadamardmatrix import iahadamardmatrix
from iahistogram import iahistogram, iahistogram_eq, iahistogram_eq1
from iahwt import iahwt
from iaidct import iaidct
from iaidft import iaidft
from iaifftshift import iaifftshift
from iaihadamard import iaihadamard
from iaihwt import iaihwt
from iaimginfo import iaimginfo
from iaind2sub import iaind2sub
from iainterpollin import iainterpollin
from iainterpolclosest import iainterpolclosest
from iaisdftsym import iaisdftsym
from iaisolines import iaisolines
from ialblshow import ialblshow
from ialog import ialog
from ialogfilter import ialogfilter
from iameshgrid import iameshgrid
from iamosaic import iamosaic
from ianeg import ianeg
from ianormalize import ianormalize
from ianshow import ianshow
from iaotsu import iaotsu
from iapad import iapad
from iapca import iapca
from iapconv import iapconv
from iapconv2 import iapconv2
from iapercentile import iapercentile
from iaphasecorr import iaphasecorr
from iaplot import iaplot
from iapolar import iapolar
from iaptrans import iaptrans
from iaramp import iaramp
from iareadurl import iareadurl
from iarectangle import iarectangle
from iaroi import iaroi
from iargb2gray import iargb2gray
from iarot90 import iarot90
from iasobel import iasobel
from iastat import iastat
from iasub2ind import iasub2ind
from iatcrgb2ind import iatcrgb2ind
from iatext import iatext
from iatile import iatile
from iatiling import iatiling
from iavarfilter import iavarfilter
from iawcorr import iawcorr
